==> s-postgray-0.8.1.tar.gz: s-postgray-0.8.1/include/su/path.h <==
/*@ (File-) Path (-descriptor) operations, path information.
 *@ TODO get_device_part, get_dir_part(), get_home(), get_tmp, is_valid, split_components, convert_separators,
 *@ TODO expand_long_name, readlink, canonicalize and/or realpath, and and and
 *
 * Copyright (c) 2021 - 2023 Steffen Nurpmeso <steffen@sdaoden.eu>.
 * SPDX-License-Identifier: ISC
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef su_PATH_H
#define su_PATH_H
#include <su/code.h>
#include <su/io-path-flags.h>
#include <su/time.h>
#define su_HEADER
#include <su/code-in.h>
C_DECL_BEGIN
struct su_pathinfo;
/* path {{{ */
/* pathinfo {{{ */
struct su_pathinfo{
	u32 pi_flags;
	su_64( u8 pi__pad[4]; )
	uz pi_nlink;
	u64 pi_ino;
	u64 pi_dev;
	u64 pi_rdev;
	uz pi_uid;
	uz pi_gid;
	u64 pi_blocks;
	uz pi_blksize;
	u64 pi_size;
	struct su_timespec pi_atime;
	struct su_timespec pi_mtime;
	struct su_timespec pi_ctime;
};
INLINE boole su__pathinfo_is(struct su_pathinfo const *pip, u32 t){
	return ((pip->pi_flags & su_IOPF_TYPE_MASK) == t);
}
EXPORT boole su_pathinfo_stat(struct su_pathinfo *self, char const *path);
EXPORT boole su_pathinfo_lstat(struct su_pathinfo *self, char const *path);
EXPORT boole su_pathinfo_fstat(struct su_pathinfo *self, sz fd);
EXPORT char su_pathinfo_descriptive_char(struct su_pathinfo const *self);
INLINE boole su_pathinfo_is_blk(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_BLK);
}
INLINE boole su_pathinfo_is_chr(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_CHR);
}
INLINE boole su_pathinfo_is_dir(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_DIR);
}
INLINE boole su_pathinfo_is_fifo(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_FIFO);
}
INLINE boole su_pathinfo_is_lnk(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_LNK);
}
INLINE boole su_pathinfo_is_reg(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_REG);
}
INLINE boole su_pathinfo_is_sock(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_SOCK);
}
/* }}} */
/* path utils {{{ */
#if !su_OS_POSIX || defined DOXYGEN
# define su_PATH_IS_DEV_STYLE 1
# define su_PATH_SEP_C '\\'
# define su_PATH_LIST_SEP_C ';'
# define su_PATH_CURRENT "."
# define su_PATH_NULL "NUL"
# define su_PATH_ROOT "c:\\"
#else
# define su_PATH_IS_DEV_STYLE 0
# define su_PATH_SEP_C '/'
# define su_PATH_LIST_SEP_C ':'
# define su_PATH_CURRENT "."
# define su_PATH_NULL "/dev/null"
# define su_PATH_ROOT "/"
#endif
#define su_PATH_AT_FDCWD -2l /* Pseudo file-descriptor referring to "current directory". */
EXPORT_DATA char const su_path_sep[2];
EXPORT_DATA char const su_path_list_sep[2];
EXPORT_DATA char const su_path_current[sizeof su_PATH_CURRENT];
EXPORT_DATA char const su_path_null[sizeof su_PATH_NULL];
EXPORT_DATA char const su_path_root[sizeof su_PATH_ROOT];
/* string */
EXPORT char const *su_path_basename(char *path);
EXPORT char const *su_path_dirname(char *path);
INLINE boole su_path_is_absolute(char const *path){
	ASSERT_RET(path != NIL, FAL0);
#if su_PATH_IS_DEV_STYLE
# error path_is_absolute
#else
	return *path == '/';
#endif
}
/* physical */
EXPORT boole su_path_access(char const *path, BITENUM_IS(u32,su_iopf_access) mode);
EXPORT boole su_path_chdir(char const *path);
EXPORT boole su_path_fchmod(sz fd, u32 permprot);
EXPORT boole su_path_is_a_tty(sz fd);
EXPORT boole su_path_link(char const *dst, char const *src);
EXPORT uz su_path_max_filename(char const *path);
EXPORT uz su_path_max_pathname(char const *path);
EXPORT boole su_path_mkdir(char const *path, BITENUM_IS(u32,su_iopf_permission) mode, boole recursive, u32 estate);
EXPORT boole su_path_rename(char const *dst, char const *src);
#ifdef su_HAVE_PATH_RM_AT
EXPORT boole su_path_rm_at(sz dirfd, char const *path, BITENUM_IS(u32,su_iopf_at) flags);
#endif
EXPORT boole su_path_rm(char const *path);
EXPORT boole su_path_rmdir(char const *path);
EXPORT boole su_path_touch(char const *path, struct su_timespec const *tsp_or_nil);
/* XXX POSIX */
EXPORT u32 su_path_umask(BITENUM_IS(u32,su_iopf_permission) perm);
/* }}} */
/* }}} */
C_DECL_END
#include <su/code-ou.h>
#endif /* su_PATH_H */
/* s-itt-mode */

==> s-postgray-0.8.3.tar.gz: s-postgray-0.8.3/include/su/path.h <==
/*@ (File-) Path (-descriptor) operations, path information.
 *@ TODO get_device_part, get_dir_part(), get_home(), get_tmp, is_valid, split_components, convert_separators,
 *@ TODO expand_long_name, readlink, canonicalize and/or realpath, and and and
 *
 * Copyright (c) 2021 - 2024 Steffen Nurpmeso <steffen@sdaoden.eu>.
 * SPDX-License-Identifier: ISC
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef su_PATH_H
#define su_PATH_H
#include <su/code.h>
#include <su/io-path-flags.h>
#include <su/time.h>
#define su_HEADER
#include <su/code-in.h>
C_DECL_BEGIN
struct su_pathinfo;
/* path {{{ */
/* pathinfo {{{ */
struct su_pathinfo{
	u32 pi_flags;
	su_64( u8 pi__pad[4]; )
	uz pi_nlink;
	u64 pi_ino;
	u64 pi_dev;
	u64 pi_rdev;
	uz pi_uid;
	uz pi_gid;
	u64 pi_blocks;
	uz pi_blksize;
	u64 pi_size;
	struct su_timespec pi_atime;
	struct su_timespec pi_mtime;
	struct su_timespec pi_ctime;
};
INLINE boole su__pathinfo_is(struct su_pathinfo const *pip, u32 t){
	return ((pip->pi_flags & su_IOPF_TYPE_MASK) == t);
}
EXPORT boole su_pathinfo_stat(struct su_pathinfo *self, char const *path);
EXPORT boole su_pathinfo_lstat(struct su_pathinfo *self, char const *path);
EXPORT boole su_pathinfo_fstat(struct su_pathinfo *self, sz fd);
EXPORT char su_pathinfo_descriptive_char(struct su_pathinfo const *self);
INLINE boole su_pathinfo_is_blk(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_BLK);
}
INLINE boole su_pathinfo_is_chr(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_CHR);
}
INLINE boole su_pathinfo_is_dir(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_DIR);
}
INLINE boole su_pathinfo_is_fifo(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_FIFO);
}
INLINE boole su_pathinfo_is_lnk(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_LNK);
}
INLINE boole su_pathinfo_is_reg(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_REG);
}
INLINE boole su_pathinfo_is_sock(struct su_pathinfo const *pip){
	ASSERT_RET(pip != NIL, FAL0);
	return su__pathinfo_is(pip, su_IOPF_SOCK);
}
/* }}} */
/* path utils {{{ */
#if !su_OS_POSIX || defined DOXYGEN
# define su_PATH_IS_DEV_STYLE 1
# define su_PATH_SEP_C '\\'
# define su_PATH_LIST_SEP_C ';'
# define su_PATH_CURRENT "."
# define su_PATH_NULL "NUL"
# define su_PATH_ROOT "c:\\"
#else
# define su_PATH_IS_DEV_STYLE 0
# define su_PATH_SEP_C '/'
# define su_PATH_LIST_SEP_C ':'
# define su_PATH_CURRENT "."
# define su_PATH_NULL "/dev/null"
# define su_PATH_ROOT "/"
#endif
#define su_PATH_AT_FDCWD -2l
EXPORT_DATA char const su_path_sep[2];
EXPORT_DATA char const su_path_list_sep[2];
EXPORT_DATA char const su_path_current[sizeof su_PATH_CURRENT];
EXPORT_DATA char const su_path_null[sizeof su_PATH_NULL];
EXPORT_DATA char const su_path_root[sizeof su_PATH_ROOT];
/* string */
EXPORT char const *su_path_basename(char *path);
EXPORT char const *su_path_dirname(char *path);
INLINE boole su_path_is_absolute(char const *path){
	ASSERT_RET(path != NIL, FAL0);
#if su_PATH_IS_DEV_STYLE
# error path_is_absolute
#else
	return *path == '/';
#endif
}
/* physical */
EXPORT boole su_path_access(char const *path, BITENUM(u32,su_iopf_access) mode);
EXPORT boole su_path_chdir(char const *path);
EXPORT boole su_path_fchmod(sz fd, u32 permprot);
EXPORT boole su_path_is_a_tty(sz fd);
EXPORT boole su_path_link(char const *dst, char const *src);
EXPORT uz su_path_max_filename(char const *path);
EXPORT uz su_path_max_pathname(char const *path);
EXPORT boole su_path_mkdir(char const *path, BITENUM(u32,su_iopf_permission) mode, boole recursive, u32 estate);
EXPORT boole su_path_rename(char const *dst, char const *src);
#if defined su_HAVE_PATH_RM_AT || defined DOXYGEN
EXPORT boole su_path_rm_at(sz dirfd, char const *path, BITENUM(u32,su_iopf_at) flags);
#endif
EXPORT boole su_path_rm(char const *path);
EXPORT boole su_path_rmdir(char const *path);
EXPORT boole su_path_touch(char const *path, struct su_timespec const *tsp_or_nil);
/* XXX POSIX */
EXPORT u32 su_path_umask(BITENUM(u32,su_iopf_permission) perm);
/* }}} */
/* }}} */
C_DECL_END
#include <su/code-ou.h>
#endif /* su_PATH_H */
/* s-itt-mode */
